==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/themed_widgets/themed_editor/editor_embed_builders_web/editor_youtube_player_web.dart <==
// 🐦 Flutter imports:
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_quill/flutter_quill.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:youtube_player_iframe/youtube_player_iframe.dart';

String? convertUrlToId(String url, {bool trimWhitespaces = true}) {
  if (!url.contains("http") && (url.length == 11)) return url;
  if (trimWhitespaces) url = url.trim();

  for (var exp in [
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")
  ]) {
    Match? match = exp.firstMatch(url);
    if (match != null && match.groupCount >= 1) return match.group(1);
  }

  return null;
}

class EditorYoutubePlayerWeb extends StatefulWidget {
  final String videoUrl;
  final bool readOnly;

  const EditorYoutubePlayerWeb({
    Key? key,
    required this.videoUrl,
    required this.readOnly,
  }) : super(key: key);

  @override
  State<EditorYoutubePlayerWeb> createState() => _WebYoutubeVideoAppState();
}

class _WebYoutubeVideoAppState extends State<EditorYoutubePlayerWeb> {
  YoutubePlayerController? _controller;
  String? _videoId;

  @override
  void initState() {
    super.initState();
    _videoId = convertUrlToId(widget.videoUrl);
    if (_videoId != null) {
      _controller = YoutubePlayerController(
        params: const YoutubePlayerParams(
          showControls: true,
          showFullscreenButton: true,
        ),
      )..onInit = () {
          _controller!.cueVideoById(videoId: _videoId!);
        };
    }
  }

  @override
  Widget build(BuildContext context) {
    final defaultStyles = DefaultStyles.getInstance(context);
    if (_controller == null || _videoId == null) {
      if (widget.readOnly) {
        return RichText(
          text: TextSpan(
            text: widget.videoUrl,
            style: defaultStyles.link,
            recognizer: TapGestureRecognizer()
              ..onTap = () => launchUrl(
                    Uri.parse(
                      widget.videoUrl,
                    ),
                  ),
          ),
        );
      }

      return RichText(
        text: TextSpan(
          text: widget.videoUrl,
          style: defaultStyles.link,
        ),
      );
    }

    return SizedBox(
      height: 300,
      child: YoutubePlayerScaffold(
        controller: _controller!,
        aspectRatio: 16 / 9,
        builder: (context, player) {
          return player;
        },
      ),
    );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/themed_widgets/themed_editor/editor_embed_builders_web/editor_youtube_player_web.dart <==
// 🐦 Flutter imports:
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_quill/flutter_quill.dart';
import 'package:verttice_ui/verttice_ui.dart';
import 'package:youtube_player_iframe/youtube_player_iframe.dart';

String? convertUrlToId(String url, {bool trimWhitespaces = true}) {
  if (!url.contains("http") && (url.length == 11)) return url;
  if (trimWhitespaces) url = url.trim();

  for (var exp in [
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")
  ]) {
    Match? match = exp.firstMatch(url);
    if (match != null && match.groupCount >= 1) return match.group(1);
  }

  return null;
}

class EditorYoutubePlayerWeb extends StatefulWidget {
  final String videoUrl;
  final bool readOnly;

  const EditorYoutubePlayerWeb({
    Key? key,
    required this.videoUrl,
    required this.readOnly,
  }) : super(key: key);

  @override
  State<EditorYoutubePlayerWeb> createState() => _WebYoutubeVideoAppState();
}

class _WebYoutubeVideoAppState extends State<EditorYoutubePlayerWeb> {
  YoutubePlayerController? _controller;
  String? _videoId;

  @override
  void initState() {
    super.initState();
    _videoId = convertUrlToId(widget.videoUrl);
    if (_videoId != null) {
      _controller = YoutubePlayerController(
        params: const YoutubePlayerParams(
          showControls: true,
          showFullscreenButton: true,
        ),
      )..onInit = () {
          _controller!.cueVideoById(videoId: _videoId!);
        };
    }
  }

  @override
  Widget build(BuildContext context) {
    final defaultStyles = DefaultStyles.getInstance(context);
    if (_controller == null || _videoId == null) {
      if (widget.readOnly) {
        return RichText(
          text: TextSpan(
            text: widget.videoUrl,
            style: defaultStyles.link,
            recognizer: TapGestureRecognizer()
              ..onTap = () => themedLaunchUrl(
                    Uri.parse(
                      widget.videoUrl,
                    ),
                  ),
          ),
        );
      }

      return RichText(
        text: TextSpan(
          text: widget.videoUrl,
          style: defaultStyles.link,
        ),
      );
    }

    return SizedBox(
      height: 300,
      child: YoutubePlayerScaffold(
        controller: _controller!,
        aspectRatio: 16 / 9,
        builder: (context, player) {
          return player;
        },
      ),
    );
  }
}
